#!/usr/bin/env python3
"""An uploader for s-ul.eu"""
import json
import requests

class SulUploadError(Exception):
    """Simple exception class for s-ul errors"""
    pass

class SulResponse:
    """A class for a response from the server"""

    domain = None
    """Domain of the uploaded file"""
    filename = None
    """Server-side filename of the uploaded file"""
    protocol = 'https://'
    """Protocol that should be used while accessing the file"""
    ext = None
    """Extension of the uploaded file"""
    url = None
    """Full URL of the uploaded file"""

    def __init__(self, answer):
        self.domain = answer.get('domain', None)
        self.filename = answer.get('filename', None)
        self.protocol = answer.get('protocol', 'https://')
        self.url = answer.get('url', None)
        self.ext = answer.get('extension', None)

class SulUploader:
    """An uploader for s-ul.eu"""

    _apiurl = 'https://s-ul.eu/api/v1/upload'
    """URL of the api endpoint"""
    def __init__(self, key):
        """Initializes the uploader

        :param key: The API key from https://s-ul.eu/account/info
        """
        self.key = key

    def upload(self, fd):
        """Uploads the file

        :param fd: File descriptor of the uploaded file
        :raises: SulUploadError if the server returned an error
        :return: A SulResponse object with response data
        """
        data = {'wizard': 'true', 'key': self.key}
        r = requests.post(self._apiurl, data=data, files={'file': fd})
        answer = json.loads(r.content.decode('utf-8'))
        if not answer.get('success', True):
            raise SulUploadError(answer['reason'])
        return SulResponse(answer)
